==> NTPubBot-0.1.16.tar.gz: NTPubBot-0.1.16/src/config_dict.py <==
import json
import os


class ConfigDict(dict):
    """Provides config persistence by writing to config.json"""

    def __init__(self):
        super().__init__()
        self.config_dir = os.path.join(os.path.expanduser("~"), ".config/ntpubbot")
        self.config_file = os.path.join(self.config_dir, "config.json")

        default_values = {
            "min_pop": 1,
            "timeout": 3600,
            "role_id": 838000652709396491,
            "channel_id": 765851775122931742,
            "message_id": 838862441428549643,
            "emoji_id": 838210540185845800,
            "discord_token": ""
        }

        if os.path.exists(self.config_dir) is False:
            os.mkdir(self.config_dir)

        if os.path.isfile(self.config_file):
            self._read_from_file()
            self._add_missing_fields(default_values)
        else:
            # Set initial key-values to provide example config.json after write
            self.update(default_values)
            self._write_to_file()

    def __setitem__(self, key, value):
        super().__setitem__(key, value)
        self._write_to_file()

    def _write_to_file(self):
        # TODO Write only modified entries instead of whole config
        try:
            with open(self.config_file, "w") as file:
                json.dump(self, file)
        except IOError:
            print("Couldn't write config. Config file doesn't exist")

    def _read_from_file(self):
        try:
            with open(self.config_file, "r") as file:
                self.update(json.load(file))
        except IOError:
            print("Couldn't read config. Config file doesn't exist")

    def _add_missing_fields(self, default_values):
        # TODO Test
        # TODO Test values for correct type
        for key, value in default_values.items():
            if key not in self.keys():
                self[key] = value


def main():
    # Call constructor to generate template config.json
    ConfigDict()

==> NTPubBot-0.2.8.tar.gz: NTPubBot-0.2.8/src/config_dict.py <==
import json
import os


# TODO Rework this to store config in variables providing type safety
class ConfigDict(dict):
    """Provides config persistence by writing to config.json"""

    def __init__(self, path=None, file=None):
        super().__init__()
        self.config_dir = path
        self.config_file = file

        if path is None:
            self.config_dir = os.path.join(os.path.expanduser("~"), ".config/ntpubbot")

        if file is None:
            self.config_file = os.path.join(self.config_dir, "config.json")

        if os.path.exists(self.config_dir) is False:
            os.mkdir(self.config_dir)

        if os.path.isfile(self.config_file):
            self._read_from_file()
            self._add_missing_fields(ConfigDict.get_default_values())
        else:
            # Set initial key-values to provide example config.json after write
            self.update(ConfigDict.get_default_values())
            self._write_to_file()

    def __setitem__(self, key, value):
        super().__setitem__(key, value)
        self._write_to_file()

    def _write_to_file(self):
        # TODO Write only modified entries instead of whole config
        try:
            with open(self.config_file, "w") as file:
                json.dump(self, file)
        except IOError:
            print("Couldn't write config. Config file doesn't exist")

    def _read_from_file(self):
        # TODO Test values for correct type
        try:
            with open(self.config_file, "r") as file:
                self.update(json.load(file))
        except IOError:
            print("Couldn't read config. Config file doesn't exist")

    def _add_missing_fields(self, default_values):
        # TODO Test
        for key, value in default_values.items():
            if key not in self.keys():
                self[key] = value

    @staticmethod
    def get_default_values():
        return {
            "min_ping_players": 3,
            "min_players": 1,
            "ping_timeout": 3600,
            "role_id": 838000652709396491,
            "notification_channel_id": 765851775122931742,
            "reaction_channel_id": 353874616155897869,
            "reaction_msg_id": 838862441428549643,
            "emoji_id": 838210540185845800,
            "discord_token": ""
        }


def main():
    # Call constructor to generate template config.json
    ConfigDict()
